==> halkyon-annotations-0.8.2.redhat-00001-sources.jar: io/dekorate/halkyon/config/ComponentConfig.java <==
package io.dekorate.halkyon.config;

import io.dekorate.project.Project;
import io.dekorate.kubernetes.config.ConfigKey;
import io.dekorate.kubernetes.config.Configuration;
import io.dekorate.halkyon.model.DeploymentMode;
import java.lang.Object;
import java.lang.String;
import io.dekorate.kubernetes.config.Env;
import java.util.Map;
import io.sundr.builder.annotations.Buildable;

@io.sundr.builder.annotations.Buildable(builderPackage = "io.dekorate.deps.kubernetes.api.builder") public class ComponentConfig extends Configuration{

    private String name = "";
    private DeploymentMode deploymentMode = io.dekorate.halkyon.model.DeploymentMode.dev;
    private boolean exposeService = false;
    private io.dekorate.kubernetes.config.Env[] envs = new io.dekorate.kubernetes.config.Env[0];
    private String buildType = "s2i";
    private String remote = "origin";

    public ComponentConfig(){
    }
    public ComponentConfig(Project project,Map<ConfigKey,Object> attributes,String name,DeploymentMode deploymentMode,boolean exposeService,io.dekorate.kubernetes.config.Env[] envs,String buildType,String remote){
            super(project, attributes);
            this.name = name != null ? name : "";
            this.deploymentMode = deploymentMode != null ? deploymentMode : io.dekorate.halkyon.model.DeploymentMode.dev;
            this.exposeService = exposeService;
            this.envs = envs != null ? envs : new io.dekorate.kubernetes.config.Env[0];
            this.buildType = buildType != null ? buildType : "s2i";
            this.remote = remote != null ? remote : "origin";
    }

    public String getName(){
            return this.name;
    }

    public DeploymentMode getDeploymentMode(){
            return this.deploymentMode;
    }

    public boolean isExposeService(){
            return this.exposeService;
    }

    public io.dekorate.kubernetes.config.Env[] getEnvs(){
            return this.envs;
    }

    public String getBuildType(){
            return this.buildType;
    }

    public String getRemote(){
            return this.remote;
    }

    public static ComponentConfigBuilder newComponentConfigBuilder(){
            return new io.dekorate.halkyon.config.ComponentConfigBuilder();
    }




}

==> halkyon-annotations-0.10.10.redhat-00001-sources.jar: io/dekorate/halkyon/config/ComponentConfig.java <==
package io.dekorate.halkyon.config;

import io.dekorate.project.Project;
import io.dekorate.kubernetes.config.ConfigKey;
import io.dekorate.kubernetes.config.Configuration;
import io.dekorate.kubernetes.config.Label;
import io.dekorate.halkyon.model.DeploymentMode;
import java.lang.Object;
import java.lang.String;
import io.dekorate.kubernetes.config.Env;
import java.util.Map;
import io.sundr.builder.annotations.Buildable;

@io.sundr.builder.annotations.Buildable(builderPackage = "io.dekorate.deps.kubernetes.api.builder") public class ComponentConfig extends Configuration{

    private String group = "";
    private String name = "";
    private String version = "";
    private DeploymentMode deploymentMode = io.dekorate.halkyon.model.DeploymentMode.dev;
    private boolean exposeService = false;
    private io.dekorate.kubernetes.config.Env[] envs = new io.dekorate.kubernetes.config.Env[0];
    private io.dekorate.kubernetes.config.Label[] labels = new io.dekorate.kubernetes.config.Label[0];
    private String buildType = "s2i";
    private String remote = "origin";

    public ComponentConfig(){
    }
    public ComponentConfig(Project project,Map<ConfigKey,Object> attributes,String group,String name,String version,DeploymentMode deploymentMode,boolean exposeService,io.dekorate.kubernetes.config.Env[] envs,io.dekorate.kubernetes.config.Label[] labels,String buildType,String remote){
            super(project, attributes);
            this.group = group != null ? group : "";
            this.name = name != null ? name : "";
            this.version = version != null ? version : "";
            this.deploymentMode = deploymentMode != null ? deploymentMode : io.dekorate.halkyon.model.DeploymentMode.dev;
            this.exposeService = exposeService;
            this.envs = envs != null ? envs : new io.dekorate.kubernetes.config.Env[0];
            this.labels = labels != null ? labels : new io.dekorate.kubernetes.config.Label[0];
            this.buildType = buildType != null ? buildType : "s2i";
            this.remote = remote != null ? remote : "origin";
    }

    public String getGroup(){
            return this.group;
    }

    public String getName(){
            return this.name;
    }

    public String getVersion(){
            return this.version;
    }

    public DeploymentMode getDeploymentMode(){
            return this.deploymentMode;
    }

    public boolean isExposeService(){
            return this.exposeService;
    }

    public io.dekorate.kubernetes.config.Env[] getEnvs(){
            return this.envs;
    }

    public io.dekorate.kubernetes.config.Label[] getLabels(){
            return this.labels;
    }

    public String getBuildType(){
            return this.buildType;
    }

    public String getRemote(){
            return this.remote;
    }

    public static ComponentConfigBuilder newComponentConfigBuilder(){
            return new io.dekorate.halkyon.config.ComponentConfigBuilder();
    }




}
